@@ -361,7 +361,7 @@ class DisplayMenu(BrowserMenu):
                                          'submenu'      : None,
                                          })                
                 else:
-                    results.append({ 'title'        : _(u'label_item_selected', default=u'Item: ${contentitem}', mapping={'title' : _safe_unicode(context.Title())}),
+                    results.append({ 'title'        : _(u'label_item_selected', default=u'Item: ${contentitem}', mapping={'contentitem' : _safe_unicode(obj[defaultPage].Title())}),
                                      'description'  : '',
                                      'action'       : None,
                                      'selected'     : True,
@@ -630,10 +630,6 @@ class WorkflowMenu(BrowserMenu):
         wf_tool = getToolByName(context, "portal_workflow")
         workflowActions = wf_tool.listActionInfos(object=context)
 
-        for action in workflowActions:
-            if action['category'] != 'workflow':
-                continue
-
         locking_info = queryMultiAdapter((context, request), name='plone_lock_info')
         if locking_info and locking_info.is_locked_for_current_user():
             return []
@@ -642,9 +638,11 @@ class WorkflowMenu(BrowserMenu):
             if action['category'] != 'workflow':
                 continue
             
+            cssClass = 'kssIgnore'
             actionUrl = action['url']
             if actionUrl == "":
                 actionUrl = '%s/content_status_modify?workflow_action=%s' % (context.absolute_url(), action['id'])
+                cssClass = ''
 
             description = ''
             
@@ -656,6 +654,7 @@ class WorkflowMenu(BrowserMenu):
                 if actionUrl.endswith(bogus):
                     if getattr(context, bogus, None) is None:
                         actionUrl = '%s/content_status_modify?workflow_action=%s' % (context.absolute_url(), action['id'],)
+                        cssClass =''
                     break
 
             if action['allowed']:
@@ -664,7 +663,7 @@ class WorkflowMenu(BrowserMenu):
                                  'action'       : actionUrl,
                                  'selected'     : False,
                                  'icon'         : None,
-                                 'extra'        : {'id' : 'workflow-transition-%s' % action['id'], 'separator' : None, 'class' : ''},
+                                 'extra'        : {'id' : 'workflow-transition-%s' % action['id'], 'separator' : None, 'class' : cssClass},
                                  'submenu'      : None,
                                  })
         
